You can find the current documentation at: https://gist.github.com/Robertobean/d54f96a858d4183ead1e8eb9c02b1264

You can find images rendered using this library here:
https://github.com/Robertobean/Pillow3f-examples

You can find documentations for the dependencies here:

Numpy: https://docs.scipy.org/doc/numpy/reference/

Pillow: https://pillow.readthedocs.io/en/5.2.x/